#!/bin/sh

#Made by sixwheeledbeast, Estel, Malkavian, peterleinchen and vi_

# Setup notification banner
banner(){
o=org
f=freedesktop
n=Notifications
run-standalone.sh dbus-send --type=method_call \
--dest=$o.$f.$n /$o/$f/$n $o.$f.$n.SystemNoteInfoprint string:"$1"
}

# Get and Print Current Swap Pre
swap=`cat /proc/swaps | awk '/dev/ {print $1}'`
echo $swap
banner "$swap"

#End of Logic
